.. _MCEq:
:html_theme.sidebar_secondary.remove: true
:html_theme.sidebar_primary.remove: true

MCEq documentation
==================
.. currentmodule:: package

**Version**: |version| | **Date**: |today|
**Useful links**: `Source Repository <https://github.com/mceq-project/mceq>`__ |
`Issue Tracker <https://github.com/mceq-project/mceq/issues>`__ |
`Pull Requests <https://github.com/mceq-project/mceq/pulls>`__
**License**: `BSD 3 <https://github.com/mceq-project/MCEq/blob/main/LICENSE>`__

This program is a toolkit to compute the evolution of particle densities that evolve
as a cascade in the Earth’s atmosphere or other target media.
Particles are represented by average densities on discrete energy bins. 
The results are differential energy spectra or total particle numbers.
Various models/parameterizations for particle interactions and atmospheric density profiles are packaged with the code.

.. toctree::
  :maxdepth: 1
  :hidden:

  quickstart/index
  tutorial
  example-gallery
  v14v13_diff
  citeus
  api-reference/index
  v12v11_diff


.. grid:: 3

  .. grid-item-card:: Quickstart
      :class-header: text-center
      :class-body: text-center
      :link: quickstart/index
      :link-type: doc

      :octicon:`goal;100px`

      ^^^^^^^^^^^^^^

      A quick tutorial on how to use MCEq.

  .. grid-item-card:: Examples Gallery
      :class-header: text-center
      :class-body: text-center
      :link: example-gallery
      :link-type: doc

      :octicon:`book;100px`

      ^^^^^^^^^^^^^^

      Check out the examples to discover the capabilities of MCEq.


  .. grid-item-card:: API Reference
      :class-header: text-center
      :class-body: text-center
      :link: api-reference/index
      :link-type: doc

      :octicon:`code;100px`

      ^^^^^^^^^^^^^^

      Find the complete API here.

